@@ -74,6 +74,7 @@ struct FMListViewDetails {
 	GtkCellRendererPixbuf *pixbuf_cell;
 	GtkCellRendererText   *file_name_cell;
 	GList *cells;
+	GtkCellEditable *editable_widget;
 
 	NautilusZoomLevel zoom_level;
 
@@ -170,6 +171,21 @@ static const char * default_trash_columns_order[] = {
 /* for EEL_CALL_PARENT */
 #define parent_class fm_list_view_parent_class
 
+static const gchar*
+get_default_sort_order (NautilusFile *file, gboolean *reversed)
+{
+	const gchar *retval;
+
+	retval = nautilus_file_get_default_sort_attribute (file, reversed);
+
+	if (retval == NULL) {
+		retval = default_sort_order_auto_value;
+		*reversed = default_sort_reversed_auto_value;
+	}
+
+	return retval;
+}
+
 static void
 list_selection_changed_callback (GtkTreeSelection *selection, gpointer user_data)
 {
@@ -491,9 +507,9 @@ motion_notify_callback (GtkWidget *widget,
 
 		if ((old_hover_path != NULL) != (view->details->hover_path != NULL)) {
 			if (view->details->hover_path != NULL) {
-				gdk_window_set_cursor (widget->window, hand_cursor);
+				gdk_window_set_cursor (gtk_widget_get_window (widget), hand_cursor);
 			} else {
-				gdk_window_set_cursor (widget->window, NULL);
+				gdk_window_set_cursor (gtk_widget_get_window (widget), NULL);
 			}
 		}
 
@@ -563,7 +579,7 @@ enter_notify_callback (GtkWidget *widget,
 					       NULL, NULL, NULL);
 
 		if (view->details->hover_path != NULL) {
-			gdk_window_set_cursor (widget->window, hand_cursor);
+			gdk_window_set_cursor (gtk_widget_get_window (widget), hand_cursor);
 		}
 	}
 
@@ -1076,6 +1092,7 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 	GtkSortType reversed;
 	GQuark sort_attr, default_sort_attr;
 	char *reversed_attr, *default_reversed_attr;
+	gboolean default_sort_reversed;
 
 	file = fm_directory_view_get_directory_as_file (FM_DIRECTORY_VIEW (view));
 
@@ -1083,12 +1100,12 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 	sort_attr = fm_list_model_get_attribute_from_sort_column_id (view->details->model, sort_column_id);
 
 	default_sort_column_id = fm_list_model_get_sort_column_id_from_attribute (view->details->model,
-										  g_quark_from_string (default_sort_order_auto_value));
+						g_quark_from_string (get_default_sort_order (file, &default_sort_reversed)));
 	default_sort_attr = fm_list_model_get_attribute_from_sort_column_id (view->details->model, default_sort_column_id);
 	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_COLUMN,
 				    g_quark_to_string (default_sort_attr), g_quark_to_string (sort_attr));
 
-	default_reversed_attr = (default_sort_reversed_auto_value ? "true" : "false");
+	default_reversed_attr = (default_sort_reversed ? "true" : "false");
 
 	if (view->details->last_sort_attr != sort_attr &&
 	    sort_criterion_changes_due_to_user (view->details->tree_view)) {
@@ -1126,6 +1143,8 @@ static void
 cell_renderer_editing_canceled (GtkCellRendererText *cell,
 				FMListView          *view)
 {
+	view->details->editable_widget = NULL;
+
 	fm_directory_view_unfreeze_updates (FM_DIRECTORY_VIEW (view));
 }
 
@@ -1139,6 +1158,8 @@ cell_renderer_edited (GtkCellRendererText *cell,
 	NautilusFile *file;
 	GtkTreeIter iter;
 
+	view->details->editable_widget = NULL;
+
 	/* Don't allow a rename with an empty string. Revert to original 
 	 * without notifying the user.
 	 */
@@ -1690,7 +1711,8 @@ set_sort_order_from_metadata_and_preferences (FMListView *list_view)
 	char *sort_attribute;
 	int sort_column_id;
 	NautilusFile *file;
-	gboolean sort_reversed;
+	gboolean sort_reversed, default_sort_reversed;
+	const gchar *default_sort_order;
 	
 	file = fm_directory_view_get_directory_as_file (FM_DIRECTORY_VIEW (list_view));
 	sort_attribute = nautilus_file_get_metadata (file,
@@ -1699,15 +1721,18 @@ set_sort_order_from_metadata_and_preferences (FMListView *list_view)
 	sort_column_id = fm_list_model_get_sort_column_id_from_attribute (list_view->details->model,
 									  g_quark_from_string (sort_attribute));
 	g_free (sort_attribute);
+
+	default_sort_order = get_default_sort_order (file, &default_sort_reversed);
+	
 	if (sort_column_id == -1) {
 		sort_column_id =
 			fm_list_model_get_sort_column_id_from_attribute (list_view->details->model,
-									 g_quark_from_string (default_sort_order_auto_value));
+									 g_quark_from_string (default_sort_order));
 	}
 
 	sort_reversed = nautilus_file_get_boolean_metadata (file,
 							    NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED,
-							    default_sort_reversed_auto_value);
+							    default_sort_reversed);
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_view->details->model),
 					      sort_column_id,
@@ -1778,11 +1803,10 @@ stop_cell_editing (FMListView *list_view)
 	 * changes directories without exiting cell edit mode. It also prevents
 	 * the edited handler from being called on the cleared list model.
 	 */
-
 	column = list_view->details->file_name_column;
-	if (column != NULL && column->editable_widget != NULL &&
-		GTK_IS_CELL_EDITABLE (column->editable_widget)) {
-		gtk_cell_editable_editing_done (column->editable_widget);
+	if (column != NULL && list_view->details->editable_widget != NULL &&
+		GTK_IS_CELL_EDITABLE (list_view->details->editable_widget)) {
+		gtk_cell_editable_editing_done (list_view->details->editable_widget);
 	}
 }
 
@@ -2254,7 +2278,7 @@ create_column_editor (FMListView *view)
 	box = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (box), 12);
 	gtk_widget_show (box);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (window)->vbox), box);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (window))), box);
 
 	label_text = _("Choose the order of information to appear in this folder:");
 	str = g_strconcat ("<b>", label_text, "</b>", NULL);
@@ -2383,6 +2407,8 @@ static void
 fm_list_view_reset_to_defaults (FMDirectoryView *view)
 {
 	NautilusFile *file;
+	const gchar *default_sort_order;
+	gboolean default_sort_reversed;
 
 	file = fm_directory_view_get_directory_as_file (view);
 
@@ -2392,11 +2418,13 @@ fm_list_view_reset_to_defaults (FMDirectoryView *view)
 	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER, NULL);
 	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS, NULL);
 
+	default_sort_order = get_default_sort_order (file, &default_sort_reversed);
+
 	gtk_tree_sortable_set_sort_column_id
 		(GTK_TREE_SORTABLE (FM_LIST_VIEW (view)->details->model),
 		 fm_list_model_get_sort_column_id_from_attribute (FM_LIST_VIEW (view)->details->model,
-								  g_quark_from_string (default_sort_order_auto_value)),
-		 default_sort_reversed_auto_value ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING);
+								  g_quark_from_string (default_sort_order)),
+		 default_sort_reversed ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING);
 
 	fm_list_view_set_zoom_level (FM_LIST_VIEW (view), get_default_zoom_level (), FALSE);
 	set_columns_settings_from_metadata_and_preferences (FM_LIST_VIEW (view));
@@ -2565,13 +2593,16 @@ fm_list_view_start_renaming_file (FMDirectoryView *view,
 	GtkTreePath *path;
 	GtkEntry *entry;
 	int start_offset, end_offset;
+	gchar *path_str;
+	GdkRectangle cell_area;
+	GdkRectangle background_area;
 	
 	list_view = FM_LIST_VIEW (view);
 	
 	/* Select all if we are in renaming mode already */
-	if (list_view->details->file_name_column && list_view->details->file_name_column->editable_widget) {
+	if (list_view->details->file_name_column && list_view->details->editable_widget) {
 		gtk_editable_select_region (
-				GTK_EDITABLE (list_view->details->file_name_column->editable_widget),
+				GTK_EDITABLE (list_view->details->editable_widget),
 				0,
 				-1);
 		return;
@@ -2585,13 +2616,21 @@ fm_list_view_start_renaming_file (FMDirectoryView *view,
 	fm_directory_view_freeze_updates (FM_DIRECTORY_VIEW (view));
 
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_view->details->model), &iter);
+	path_str = gtk_tree_path_to_string (path);
+	gtk_tree_view_get_cell_area (list_view->details->tree_view, path,
+				     list_view->details->file_name_column, &cell_area);
+	gtk_tree_view_get_background_area (list_view->details->tree_view, path,
+					   list_view->details->file_name_column, &background_area);
 
-	/*Make filename-cells editable.*/
+	/* Make filename-cells editable. */
 	g_object_set (G_OBJECT (list_view->details->file_name_cell),
 		      "editable", TRUE,
 		      NULL);
 
-	
+	list_view->details->editable_widget =
+		gtk_cell_renderer_start_editing (GTK_CELL_RENDERER (list_view->details->file_name_cell),
+						 NULL, NULL, path_str, &background_area,
+						 &cell_area, 0);
 	gtk_tree_view_scroll_to_cell (list_view->details->tree_view,
 				      NULL,
 				      list_view->details->file_name_column,
@@ -2601,7 +2640,7 @@ fm_list_view_start_renaming_file (FMDirectoryView *view,
 				  list_view->details->file_name_column,
 				  TRUE);
 
-	entry = GTK_ENTRY (list_view->details->file_name_column->editable_widget);
+	entry = GTK_ENTRY (list_view->details->editable_widget);
 
 	/* Free a previously allocated original_name */
 	g_free (list_view->details->original_name);
@@ -2650,7 +2689,7 @@ fm_list_view_click_policy_changed (FMDirectoryView *directory_view)
 
 		tree = view->details->tree_view;
 		if (gtk_widget_get_realized (GTK_WIDGET (tree))) {
-			win = GTK_WIDGET (tree)->window;
+			win = gtk_widget_get_window (GTK_WIDGET (tree));
 			gdk_window_set_cursor (win, NULL);
 			
 			display = gtk_widget_get_display (GTK_WIDGET (view));
