@@ -163,6 +163,9 @@ action_split_view_same_location_callback (GtkAction *action,
 	window = NAUTILUS_WINDOW (user_data);
 	next_pane = nautilus_window_get_next_pane (window);
 
+	if (!next_pane) {
+		return;
+	}
 	location = nautilus_window_slot_get_location (next_pane->active_slot);
 	if (location) {
 		nautilus_window_slot_go_to (window->details->active_pane->active_slot, location, FALSE);
@@ -261,11 +264,17 @@ action_split_view_callback (GtkAction *action,
 
 	is_active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (is_active != nautilus_navigation_window_split_view_showing (window)) {
+		NautilusWindow *nautilus_window;
+
 		if (is_active) {
 			nautilus_navigation_window_split_view_on (window);
 		} else {
 			nautilus_navigation_window_split_view_off (window);
 		}
+		nautilus_window = NAUTILUS_WINDOW (window);
+		if (nautilus_window->details->active_pane && nautilus_window->details->active_pane->active_slot) {
+			nautilus_view_update_menus (nautilus_window->details->active_pane->active_slot->content_view);
+		}
 	}
 }
 
@@ -389,7 +398,7 @@ connect_proxy_cb (GtkActionGroup *action_group,
 	if (!GTK_IS_MENU_ITEM (proxy))
 		return;
 
-	label = GTK_LABEL (GTK_BIN (proxy)->child);
+	label = GTK_LABEL (gtk_bin_get_child (GTK_BIN (proxy)));
 
 	gtk_label_set_use_underline (label, FALSE);
 	gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
@@ -698,10 +707,13 @@ action_show_hide_search_callback (GtkAction *action,
 			char *uri;
 
 			query = nautilus_query_editor_get_query (slot->query_editor);
-			uri = nautilus_query_get_location (query);
-			if (uri != NULL) {
-				location = g_file_new_for_uri (uri);
-				g_free (uri);
+			if (query != NULL) {
+				uri = nautilus_query_get_location (query);
+				if (uri != NULL) {
+					location = g_file_new_for_uri (uri);
+					g_free (uri);
+				}
+				g_object_unref (query);
 			}
 		}
 
