@@ -144,7 +144,7 @@ set_displayed_location (NautilusWindowSlot *slot, GFile *location)
 		slot->last_location_bookmark = slot->current_location_bookmark;
 		name = g_file_get_uri (location);
 		slot->current_location_bookmark = (location == NULL) ? NULL
-                        : nautilus_bookmark_new (location, name);
+                        : nautilus_bookmark_new (location, name, TRUE, NULL);
 		g_free (name);
         }
 }
@@ -1399,7 +1399,7 @@ location_has_really_changed (NautilusWindowSlot *slot)
 	if (slot->new_content_view != NULL) {
 		widget = nautilus_view_get_widget (slot->new_content_view);
 		/* Switch to the new content view. */
-		if (widget->parent == NULL) {
+		if (gtk_widget_get_parent (widget) == NULL) {
 			if (slot->content_view != NULL) {
 				nautilus_window_slot_disconnect_content_view (slot, slot->content_view);
 			}
